<?php
/**
 * @file
 * Linkit admin settings.
 */

/**
 * Linkit settings form.
 */
function linkit_settings_form($form, &$form_state) {
  $menu = variable_get('linkit_menu', array());

  // Linkit fieldset.
  $form['linkit_menu'] = array(
    '#type' => 'fieldset',
    '#title' => t('Menu settings'),
    '#tree' => TRUE,
  );

  // Enable Linkit.
  $form['linkit_menu']['enable'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Linkit for menu links.'),
    '#default_value' => isset($menu['enable']) ? $menu['enable'] : FALSE,
  );

  // Load profile options.
  $profiles = linkit_profile_field_load_all();
  $options = array();
  foreach ($profiles as $profile) {
    $options[$profile->name] = $profile->admin_title;
  }
  natsort($options);

  // Linkit profile.
  $form['linkit_menu']['profile'] = array(
    '#type' => 'select',
    '#title' => t('Profile'),
    '#options' => $options,
    '#empty_option' => t('- Select a profile -'),
    '#default_value' => isset($menu['profile']) ? $menu['profile'] : '',
    '#states' => array(
      'invisible' => array(
        'input[name="linkit_menu[enable]"]' => array('checked' => FALSE),
      ),
      'required' => array(
        'input[name="linkit_menu[enable]"]' => array('checked' => TRUE),
      ),
    ),
    '#element_validate' => array('linkit_menu_profile_validate'),
  );

  // Button text.
  $form['linkit_menu']['button_text'] = array(
    '#type' => 'textfield',
    '#title' => t('Button text that activates Linkit modal'),
    '#default_value' => isset($menu['button_text']) ? $menu['button_text'] : t('Search'),
    '#states' => array(
      'invisible' => array(
        'input[name="linkit_menu[enable]"]' => array('checked' => FALSE),
      ),
    ),
  );

  return system_settings_form($form);
}

/**
 * Validation callback which validates profile field if linkit is enabled for
 * menus.
 *
 * @see linkit_form_menu_edit_menu_alter()
 */
function linkit_menu_profile_validate($element, &$form_state, $form) {
  if (!empty($form_state['values']['menu']['enable']) && empty($element['#value'])) {
    form_error($element, t('You must select a Linkit profile.'));
  }
}
